@@ -1,8 +1,8 @@
-## IO.R (2019-11-15)
+## IO.R (2021-03-22)
 
 ##   Input/Ouput
 
-## Copyright 2009-2019 Emmanuel Paradis
+## Copyright 2009-2021 Emmanuel Paradis
 
 ## This file is part of the R-package `pegas'.
 ## See the file ../DESCRIPTION for licensing issues.
@@ -184,3 +184,70 @@ edit.loci <- function(name, edit.row.names = TRUE, ...)
     attr(name, "locicol") <- locicol
     name
 }
+
+write.vcf <- function(x, file, CHROM = NULL, POS = NULL, quiet = FALSE)
+{
+    if (!inherits(x, "loci")) stop("'x' should be of class \"loci\"")
+    ALLELES <- summary(x)
+    ALLELES <- lapply(ALLELES, "[[", "allele")
+    LOCI <- attr(x, "locicol")
+    nLOCI <- length(LOCI)
+    if (is.null(CHROM)) {
+        CHROM <- rep(".", nLOCI)
+    } else {
+        if (length(CHROM) != nLOCI)
+            stop("length of 'CHROM' must be equal to the number of loci")
+    }
+    if (is.null(POS)) {
+        POS <- rep(".", nLOCI)
+    } else {
+        if (length(POS) != nLOCI)
+            stop("length of 'POS' must be equal to the number of loci")
+    }
+    NAMES <- names(x)
+    if (file.exists(file)) unlink(file)
+    con <- file(file, "ab")
+    tmp <- paste0(c("##fileformat=VCFv4.1\n##File produced by pegas (",
+                    date(), ")\n##QUAL=<missingValue=9999>\n"), collapse = "")
+    writeBin(charToRaw(tmp), con)
+    tmp <- paste0(c("#CHROM\tPOS\tID\tREF\tALT\tQUAL\tFILTER\tINFO\tFORMAT",
+                    row.names(x)), collapse = "\t")
+    LF <- charToRaw("\n")
+    writeBin(c(charToRaw(tmp), LF), con)
+    class(x) <- NULL
+    i <- 0L
+    for (j in LOCI) {
+        i <- i + 1L
+        if (!quiet && j %% 100 == 0) cat("\r", j, "/", length(LOCI))
+        alls <- sort.int(ALLELES[[j]], decreasing = TRUE, method = "quick")
+        nalls <- length(alls)
+        allele.names <- names(alls)
+        withDotAllele <- any(s <- allele.names == ".")
+        y <- x[[j]]
+
+        ## if only missing data for this locus, no need to translate the genotypes
+        if (!(withDotAllele && nalls == 1)) {
+            if (withDotAllele) {
+                alls <- alls[!s]
+                allele.names <- allele.names[!s]
+                nalls <- nalls - 1L
+            }
+            REF <- allele.names[1]
+            ALT <- if (nalls == 1) "." else allele.names[-1]
+            geno <- levels(y)
+            ngeno <- length(geno)
+            newgeno <- character(ngeno)
+            o <- .C(translateGenotypesForVCF, geno, newgeno, ngeno, allele.names, nalls)
+            newgeno <- o[[2]]
+            y <- newgeno[as.integer(y)]
+            if (nalls > 2) ALT <- paste0(ALT, collapse = ",")
+        }
+
+        tmp <- paste0(c(CHROM[i], POS[i], NAMES[j], REF, ALT,
+                      "9999\t.\t.\tGT", y), collapse = "\t")
+        writeBin(c(charToRaw(tmp), LF), con)
+    }
+    close(con)
+    if (!quiet) cat("\n")
+}
+
